@@ -59,6 +59,21 @@ class FakePreseemModel:
             if sites is None:
                 sites = FakePreseemModel._sites[company_uuid] = {}
             sites[obj.uuid] = obj
+        for obj in await other.Package.List(company_uuid=company_uuid):
+            packages = FakePreseemModel._packages.get(company_uuid)
+            if packages is None:
+                packages = FakePreseemModel._packages[company_uuid] = {}
+            packages[obj.uuid] = obj
+        for obj in await other.Account.List(company_uuid=company_uuid):
+            accounts = FakePreseemModel._accounts.get(company_uuid)
+            if accounts is None:
+                accounts = FakePreseemModel._accounts[company_uuid] = {}
+            accounts[obj.uuid] = obj
+        for obj in await other.Service.List(company_uuid=company_uuid):
+            services = FakePreseemModel._services.get(company_uuid)
+            if services is None:
+                services = FakePreseemModel._services[company_uuid] = {}
+            services[obj.uuid] = obj
 
     """Fake preseem model that implements the python API."""
 
@@ -438,9 +453,10 @@ class FakePreseemModel:
             if services:
                 service = services.get(uuid)
                 for attr, val in kwargs.items():
-                    if attr == 'attachment':
+                    if attr == 'attachment_req':
                         if val:
                             assert isinstance(val, SetAttachmentReq)
+                            attr = 'attachment'
                             val = val.attachment
                     if attr == 'company_uuid' or attr == 'uuid':
                         continue
