@@ -124,7 +124,7 @@ async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, creat
                         set_att_req = SetAttachmentReq()
                         if attachment:
                             set_att_req.attachment.CopyFrom(attachment)
-                        mods['attachment'] = set_att_req
+                        mods['attachment_req'] = set_att_req
                     await call_and_log_error(
                         updaterpc(company_uuid=company_uuid, uuid=mobj.uuid, **mods))
         else:
@@ -191,7 +191,8 @@ async def sync_preseem_model(preseem_model,
             preseem_model.Account.List(company_uuid=company_uuid),
             preseem_model.Element.ListElementDiscovery(company_uuid=company_uuid,
                                                        intent_role_uuid=role.bytes),
-            preseem_model.Service.List(company_uuid=company_uuid),
+            preseem_model.Service.List(company_uuid=company_uuid,
+                                       include_attachment=True),
             preseem_model.Site.List(company_uuid=company_uuid),
             preseem_model.Package.List(company_uuid=company_uuid))
 
