@@ -1278,6 +1278,236 @@ class Interface:
             self.pb.poller_hash = value
 
 
+class IpMac:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.IpMac()
+        self.errctx = errctx
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def ip_address(self):
+        return self.pb.ip_address
+
+    @ip_address.setter
+    def ip_address(self, value):
+        if value is not None:
+            self.pb.ip_address = value
+
+    @property
+    def mac_address(self):
+        return self.pb.mac_address
+
+    @mac_address.setter
+    def mac_address(self, value):
+        if value is not None:
+            self.pb.mac_address = value
+
+    @property
+    def port(self):
+        return self.pb.port if self.pb.HasField('port') else None
+
+    @port.setter
+    def port(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.port = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElementUpdate.IpMac.port',
+                                value=value,
+                                metric_name='NetworkElementUpdate.IpMac.port')
+        else:
+            self.pb.ClearField('port')
+
+
+class Route:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.Route()
+        self.errctx = errctx
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def net(self):
+        return self.pb.net
+
+    @net.setter
+    def net(self, value):
+        if value is not None:
+            self.pb.net = value
+
+    @property
+    def if_index(self):
+        return self.pb.if_index if self.pb.HasField('if_index') else None
+
+    @if_index.setter
+    def if_index(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.if_index = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElementUpdate.Route.if_index',
+                                value=value,
+                                metric_name='NetworkElementUpdate.Route.if_index')
+        else:
+            self.pb.ClearField('if_index')
+
+    @property
+    def next_hop(self):
+        return self.pb.next_hop if self.pb.HasField('next_hop') else None
+
+    @next_hop.setter
+    def next_hop(self, value):
+        if value is not None:
+            self.pb.next_hop = value
+        else:
+            self.pb.ClearField('next_hop')
+
+    @property
+    def mac_address(self):
+        return self.pb.mac_address if self.pb.HasField('mac_address') else None
+
+    @mac_address.setter
+    def mac_address(self, value):
+        if value is not None:
+            self.pb.mac_address = value
+        else:
+            self.pb.ClearField('mac_address')
+
+
+class DhcpLease:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.DhcpLease()
+        self.errctx = errctx
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def ip_address(self):
+        return self.pb.ip_address
+
+    @ip_address.setter
+    def ip_address(self, value):
+        if value is not None:
+            self.pb.ip_address = value
+
+    @property
+    def mac_address(self):
+        return self.pb.mac_address
+
+    @mac_address.setter
+    def mac_address(self, value):
+        if value is not None:
+            self.pb.mac_address = value
+
+    @property
+    def circuit_id(self):
+        return self.pb.circuit_id if self.pb.HasField('circuit_id') else None
+
+    @circuit_id.setter
+    def circuit_id(self, value):
+        if value is not None:
+            self.pb.circuit_id = value
+        else:
+            self.pb.ClearField('circuit_id')
+
+    @property
+    def remote_id(self):
+        return self.pb.remote_id if self.pb.HasField('remote_id') else None
+
+    @remote_id.setter
+    def remote_id(self, value):
+        if value is not None:
+            self.pb.remote_id = value
+        else:
+            self.pb.ClearField('remote_id')
+
+    @property
+    def hostname(self):
+        return self.pb.hostname if self.pb.HasField('hostname') else None
+
+    @hostname.setter
+    def hostname(self, value):
+        if value is not None:
+            self.pb.hostname = value
+        else:
+            self.pb.ClearField('hostname')
+
+
+class PppoeClient:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.PppoeClient()
+        self.errctx = errctx
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def if_name(self):
+        return self.pb.if_name if self.pb.HasField('if_name') else None
+
+    @if_name.setter
+    def if_name(self, value):
+        if value is not None:
+            self.pb.if_name = value
+        else:
+            self.pb.ClearField('if_name')
+
+    @property
+    def if_index(self):
+        return self.pb.if_index if self.pb.HasField('if_index') else None
+
+    @if_index.setter
+    def if_index(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.if_index = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElementUpdate.PppoeClient.if_index',
+                    value=value,
+                    metric_name='NetworkElementUpdate.PppoeClient.if_index')
+        else:
+            self.pb.ClearField('if_index')
+
+    @property
+    def username(self):
+        return self.pb.username
+
+    @username.setter
+    def username(self, value):
+        if value is not None:
+            self.pb.username = value
+
+    @property
+    def mac_address(self):
+        return self.pb.mac_address if self.pb.HasField('mac_address') else None
+
+    @mac_address.setter
+    def mac_address(self, value):
+        if value is not None:
+            self.pb.mac_address = value
+        else:
+            self.pb.ClearField('mac_address')
+
+    @property
+    def ip_address(self):
+        return self.pb.ip_address if self.pb.HasField('ip_address') else None
+
+    @ip_address.setter
+    def ip_address(self, value):
+        if value is not None:
+            self.pb.ip_address = value
+        else:
+            self.pb.ClearField('ip_address')
+
+
 class NetworkElement:
 
     def __init__(self, pb=None, errctx=None, **kwargs):
@@ -1521,6 +1751,10 @@ class NetworkElementUpdate:
             setattr(self, key, value)
         self.errors = Repeated(None, self.pb.errors, self.errctx)
         self.peers = Repeated(NetworkElement, self.pb.peers, self.errctx)
+        self.ip_macs = Repeated(IpMac, self.pb.ip_macs, self.errctx)
+        self.routes = Repeated(Route, self.pb.routes, self.errctx)
+        self.dhcp_leases = Repeated(DhcpLease, self.pb.dhcp_leases, self.errctx)
+        self.pppoe_clients = Repeated(PppoeClient, self.pb.pppoe_clients, self.errctx)
 
     @property
     def time(self):
@@ -1564,9 +1798,7 @@ class NetworkElementUpdate:
 
     @poller_version.setter
     def poller_version(self, value):
-        if value is None:
-            self.pb.ClearField('poller_version')
-        else:
+        if value is not None:
             self.pb.poller_version = value
 
     @property
