@@ -77,6 +77,151 @@ class TestNetworkElementUpdate(unittest.TestCase):
         del neu.peers[0]
         self.assertEqual(len(neu.peers), 0)
 
+        # Test IpMac
+        self.assertEqual(list(neu.ip_macs), [])
+        ip_mac = neu.ip_macs.add()
+        self.assertEqual(len(neu.ip_macs), 1)
+
+        ip_mac.ip_address = "1.2.3.4"
+        self.assertEqual(ip_mac.ip_address, "1.2.3.4")
+
+        ip_mac.mac_address = "0a:00:00:01:02:01"
+        self.assertEqual(ip_mac.mac_address, "0a:00:00:01:02:01")
+
+        ip_mac.errctx = network_element_update.ErrorContext()
+        self.assertEqual(ip_mac.port, None)
+        ip_mac.port = 12
+        self.assertEqual(ip_mac.port, 12)
+        ip_mac.port = -1
+        self.assertEqual(ip_mac.port, 12)
+        ip_mac.port = pow(2, 31) + 1
+        self.assertEqual(ip_mac.port, 12)
+        ip_mac.port = None
+        self.assertEqual(len(ip_mac.errctx.errors), 2)
+        ip_mac.errctx = None
+        
+        del neu.ip_macs[0]
+        self.assertEqual(len(neu.ip_macs), 0)
+
+
+        # Test Route
+        self.assertEqual(list(neu.routes), [])
+        route = neu.routes.add()
+        self.assertEqual(len(neu.routes), 1)
+
+        self.assertEqual(route.net, "")
+        route.net = "0b:00:00:01:02:01"
+        self.assertEqual(route.net, "0b:00:00:01:02:01")
+
+        route.errctx = network_element_update.ErrorContext()
+        self.assertEqual(route.if_index, None)
+        route.if_index = 11
+        self.assertEqual(route.if_index, 11)
+        route.if_index = -1
+        self.assertEqual(route.if_index, 11)
+        route.if_index = pow(2, 31) + 1
+        self.assertEqual(route.if_index, 11)
+        route.if_index = None
+        self.assertEqual(len(route.errctx.errors), 2)
+        route.errctx = None
+
+        next_hop = '0b:00:00:01:02:03'
+        self.assertEqual(route.next_hop, None)
+        route.next_hop = next_hop
+        self.assertEqual(route.next_hop, next_hop)
+        route.next_hop = None
+        self.assertEqual(route.next_hop, None)
+
+        mac_address = '0b:00:00:01:02:04'
+        self.assertEqual(route.mac_address, None)
+        route.mac_address = mac_address
+        self.assertEqual(route.mac_address, mac_address)
+        route.mac_address = None
+        self.assertEqual(route.mac_address, None)
+
+        del neu.routes[0]
+        self.assertEqual(len(neu.routes), 0)
+
+
+        # Test DhcpLease
+        self.assertEqual(list(neu.dhcp_leases), [])
+        dhcp_lease = neu.dhcp_leases.add()
+        self.assertEqual(len(neu.dhcp_leases), 1)
+
+        dhcp_lease.ip_address = "1.2.3.4"
+        self.assertEqual(dhcp_lease.ip_address, "1.2.3.4")
+
+        dhcp_lease.mac_address = "0a:00:00:01:02:01"
+        self.assertEqual(dhcp_lease.mac_address, "0a:00:00:01:02:01")
+
+        circuit_id = '0b:00:00:01:02:07'
+        self.assertEqual(dhcp_lease.circuit_id, None)
+        dhcp_lease.circuit_id = circuit_id
+        self.assertEqual(dhcp_lease.circuit_id, circuit_id)
+        dhcp_lease.circuit_id = None
+        self.assertEqual(dhcp_lease.circuit_id, None)
+
+        remote_id = '0b:00:00:01:02:08'
+        self.assertEqual(dhcp_lease.remote_id, None)
+        dhcp_lease.remote_id = remote_id
+        self.assertEqual(dhcp_lease.remote_id, remote_id)
+        dhcp_lease.remote_id = None
+        self.assertEqual(dhcp_lease.remote_id, None)
+
+        hostname = 'testhost1'
+        self.assertEqual(dhcp_lease.hostname, None)
+        dhcp_lease.hostname = hostname
+        self.assertEqual(dhcp_lease.hostname, hostname)
+        dhcp_lease.hostname = None
+        self.assertEqual(dhcp_lease.hostname, None)
+
+        del neu.dhcp_leases[0]
+        self.assertEqual(len(neu.dhcp_leases), 0)
+
+        # Test PppoeClient
+        self.assertEqual(list(neu.pppoe_clients), [])
+        pppoe_client = neu.pppoe_clients.add()
+        self.assertEqual(len(neu.pppoe_clients), 1)
+
+        if_name = 'testifname1'
+        self.assertEqual(pppoe_client.if_name, None)
+        pppoe_client.if_name = if_name
+        self.assertEqual(pppoe_client.if_name, if_name)
+        pppoe_client.if_name = None
+        self.assertEqual(pppoe_client.if_name, None)
+
+        pppoe_client.errctx = network_element_update.ErrorContext()
+        self.assertEqual(pppoe_client.if_index, None)
+        pppoe_client.if_index = 11
+        self.assertEqual(pppoe_client.if_index, 11)
+        pppoe_client.if_index = -1
+        self.assertEqual(pppoe_client.if_index, 11)
+        pppoe_client.if_index = pow(2, 31) + 1
+        self.assertEqual(pppoe_client.if_index, 11)
+        pppoe_client.if_index = None
+        self.assertEqual(len(pppoe_client.errctx.errors), 2)
+        pppoe_client.errctx = None
+
+        pppoe_client.username = "user1"
+        self.assertEqual(pppoe_client.username, "user1")
+
+        ip_address = '0b:00:00:01:02:03'
+        self.assertEqual(pppoe_client.ip_address, None)
+        pppoe_client.ip_address = ip_address
+        self.assertEqual(pppoe_client.ip_address, ip_address)
+        pppoe_client.ip_address = None
+        self.assertEqual(pppoe_client.ip_address, None)
+
+        mac_address = '0b:00:00:01:02:04'
+        self.assertEqual(pppoe_client.mac_address, None)
+        pppoe_client.mac_address = mac_address
+        self.assertEqual(pppoe_client.mac_address, mac_address)
+        pppoe_client.mac_address = None
+        self.assertEqual(pppoe_client.mac_address, None)
+
+        del neu.pppoe_clients[0]
+        self.assertEqual(len(neu.pppoe_clients), 0)
+
         # Check copy behavior of sub-message assignment
         ne = network_element_update.NetworkElement()
         self.assertEqual(ne.management_ip, None)
